@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2010      Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -19,11 +20,14 @@
 #include <stdio.h>
 
 #include "ompi/mpi/c/bindings.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
 #include "ompi/mpi/f77/fint_2_int.h"
 #include "ompi/mpi/f77/constants.h"
 #include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Status_c2f = PMPI_Status_c2f
 #endif
 
@@ -63,16 +67,31 @@ int MPI_Status_c2f(MPI_Status *c_status, MPI_Fint *f_status)
         }
     }
 
+    /* Note that MPI-2.2 16.3.5 states that even the hidden data in a
+       status must be converted (!).  This is somewhat problematic
+       because the Fortran data is all INTEGERS while the C MPI_Status
+       contains a size_t.  That being said, note 2 things:
+
+       1. The _ucount and _canceled members are never accessed from
+          Fortran.
+       2. configure calculated a value of MPI_STATUS_SIZE to ensure
+          that the Fortran status is the Right size to hold the C
+          MPI_Status (including the size_t member).
+
+       So for the purposes of this function, just copy over all the
+       data as if they were int's.  This works because all OMPI
+       Fortran MPI API functions that take a status as an IN argument
+       first call MPI_Status_f2c on it before using it (in which case
+       we'll do the exact opposite copy, thereby rebuilding the size_t
+       value properly before it is accessed in C).
+
+       Note that if sizeof(int) > sizeof(INTEGER), we're potentially
+       hosed anyway (i.e., even the public values in the status could
+       get truncated).  But if sizeof(int) == sizeof(INTEGER) or
+       sizeof(int) < sizeof(INTEGER), everything should be kosher. */
     c_ints = (int*)c_status;
     for( i = 0; i < (int)(sizeof(MPI_Status) / sizeof(int)); i++ )
         f_status[i] = OMPI_INT_2_FINT(c_ints[i]);
 
-    /*
-    f_status[0] = OMPI_INT_2_FINT(c_status->MPI_SOURCE);
-    f_status[1] = OMPI_INT_2_FINT(c_status->MPI_TAG);
-    f_status[2] = OMPI_INT_2_FINT(c_status->MPI_ERROR);
-    f_status[3] = OMPI_INT_2_FINT(c_status->_count);
-    f_status[4] = OMPI_INT_2_FINT(c_status->_cancelled);
-    */
     return MPI_SUCCESS;
 }
